import React from 'react';
import { ElementBlock } from './ElementBlock';
import { ElementWebframe } from './ElementWebframe';
import { ElementCard } from './ElementCard';
import { ElementIcon } from './ElementIcon';
import { ElementCodeBlock } from './ElementCodeBlock';
import { ElementImage } from './ElementImage';
import { ElementStack } from './ElementStack';
import { ElementText } from './ElementText';
import { ElementButton } from './ElementButton';
import { ElementModal } from './ElementModal';
import { ElementBox } from './ElementBox';
import { ElementMarkdown } from './ElementMarkdown';
import { ElementTextInput } from './ElementTextInput';
import { ElementDivider } from './ElementDivider';
export function Element(props) {
    const { element, context, state } = props;
    switch (element.type) {
        case 'text':
            return (React.createElement(ElementText, { element: element, context: context, state: state },
                React.createElement(Elements, { elements: element.children, context: context, state: state })));
        case 'block':
            return (React.createElement(ElementBlock, { element: element, context: context, state: state },
                React.createElement(Elements, { elements: element.children, context: context, state: state })));
        case 'box':
            return (React.createElement(ElementBox, { element: element, context: context, state: state },
                React.createElement(Elements, { elements: element.children, context: context, state: state })));
        case 'divider':
            return React.createElement(ElementDivider, { element: element, context: context, state: state });
        case 'markdown':
            return React.createElement(ElementMarkdown, { element: element, context: context, state: state });
        case 'modal': {
            const content = (React.createElement(ElementModal, { element: element, subtitle: element.subtitle ? (React.createElement(Elements, { elements: ensureStackElements('hstack', element.subtitle, 'start'), context: context, state: state })) : null },
                React.createElement(Elements, { elements: element.children, context: context, state: state })));
            if (context.modalWrapper) {
                const ModalWrapper = context.modalWrapper;
                return React.createElement(ModalWrapper, null, content);
            }
            return content;
        }
        case 'image': {
            return React.createElement(ElementImage, { element: element, context: context, state: state });
        }
        case 'button': {
            return (React.createElement(ElementButton, { element: element, icon: element.icon ? React.createElement(ElementIcon, { icon: element.icon, context: context }) : null, trailingIcon: element.trailingIcon ? (React.createElement(ElementIcon, { icon: element.trailingIcon, context: context })) : null }));
        }
        case 'textinput': {
            return React.createElement(ElementTextInput, { element: element });
        }
        case 'hstack':
        case 'vstack':
            return (React.createElement(ElementStack, { element: element, context: context, state: state },
                React.createElement(Elements, { elements: element.children, context: context, state: state })));
        case 'card':
            return (React.createElement(ElementCard, { element: element, icon: element.icon ? (typeof element.icon === 'string' ? (React.createElement(ElementIcon, { icon: element.icon, context: context })) : (React.createElement(Element, { element: element.icon, context: context, state: state }))) : null, hint: element.hint ? (typeof element.hint === 'string' ? (element.hint) : (React.createElement(Elements, { elements: ensureStackElements('hstack', element.hint, 'start'), context: context, state: state }))) : null, buttons: element.buttons
                    ? element.buttons.map((button, index) => (React.createElement(Element, { key: index, element: button, context: context, state: state })))
                    : [] }, element.children ? (React.createElement(Elements, { elements: element.children, context: context, state: state })) : null));
        case 'codeblock':
            return React.createElement(ElementCodeBlock, { element: element, context: context, state: state });
        case 'webframe':
            return React.createElement(ElementWebframe, { element: element });
        default:
            return (React.createElement("pre", { style: { display: process.env.NODE_ENV === 'development' ? 'block' : 'hidden' } },
                "ContentKit element not implemented \"",
                element.type,
                "\":",
                ' ',
                JSON.stringify(element, null, 2)));
    }
}
function Elements(props) {
    const { context, state } = props;
    const elements = Array.isArray(props.elements) ? props.elements : [props.elements];
    return (React.createElement(React.Fragment, null, elements.map((element, index) => {
        if (typeof element === 'string') {
            return React.createElement(React.Fragment, { key: index }, element);
        }
        return React.createElement(Element, { key: index, element: element, context: context, state: state });
    })));
}
/**
 * Ensure a set of elements are going to be rendered as a stack (either hstack or vstack).
 * If the elements are already a stack, return them as is.
 */
function ensureStackElements(type, elements, align) {
    if (elements.length === 1) {
        return elements;
    }
    return [{ type, align, children: elements }];
}
